namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Image::extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type width,  ::efl::eolian::out_traits<int>::type height) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_width = {};
   int __out_param_height = {};
    ::elm_interface_atspi_image_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y
      , & __out_param_width
      , & __out_param_height);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(width, __out_param_width);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(height, __out_param_height);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Image::description_get() const
{
   const char * __return_value =  ::elm_interface_atspi_image_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Image::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
    ::elm_interface_atspi_image_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Image::locale_get() const
{
   const char * __return_value =  ::elm_interface_atspi_image_locale_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
} } 
namespace eo_cxx {
namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Image::extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y,  ::efl::eolian::out_traits<int>::type width,  ::efl::eolian::out_traits<int>::type height) const
{
   int __out_param_x = {};
   int __out_param_y = {};
   int __out_param_width = {};
   int __out_param_height = {};
    ::elm_interface_atspi_image_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_x
      , & __out_param_y
      , & __out_param_width
      , & __out_param_height);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(width, __out_param_width);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(height, __out_param_height);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Image::description_get() const
{
   const char * __return_value =  ::elm_interface_atspi_image_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<void>::type Atspi_Image::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
    ::elm_interface_atspi_image_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
}
#endif
#ifdef ELM_INTERFACE_ATSPI_IMAGE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Image::locale_get() const
{
   const char * __return_value =  ::elm_interface_atspi_image_locale_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
inline elm::interface::Atspi_Image::operator ::elm::interface::Atspi_Image() const { return *static_cast< ::elm::interface::Atspi_Image const*>(static_cast<void const*>(this)); }
inline elm::interface::Atspi_Image::operator ::elm::interface::Atspi_Image&() { return *static_cast< ::elm::interface::Atspi_Image*>(static_cast<void*>(this)); }
inline elm::interface::Atspi_Image::operator ::elm::interface::Atspi_Image const&() const { return *static_cast< ::elm::interface::Atspi_Image const*>(static_cast<void const*>(this)); }
} } }

